Examples
========

This section contains examples of using AutoReduce for different types of model reduction tasks.

Michaelis-Menten Model Reduction
-------------------------------

This example demonstrates how to reduce a simple Michaelis-Menten model using QSSA.

.. nbgallery::
   :caption: Michaelis-Menten Example
   :name: michaelis-menten

   ../examples/michaelis-menten example.ipynb

Gene Expression Analysis
-----------------------

This example shows how to analyze and reduce gene expression models.

.. nbgallery::
   :caption: Gene Expression Analysis
   :name: gene-expression

   ../examples/gene expression analysis.ipynb

BioCRNPyler Integration
----------------------

This example demonstrates how to use AutoReduce with BioCRNPyler for synthetic biology models.

.. nbgallery::
   :caption: BioCRNPyler Integration
   :name: biocrnpyler

   ../examples/AutoReduce-BioCRNpyler interface.ipynb

Each example notebook contains detailed explanations and can be downloaded from the `GitHub repository <https://github.com/ayush9pandey/AutoReduce/tree/main/examples>`_.
